@@ -3,7 +3,7 @@ import re
 import datetime
 from moto.core import BaseBackend, BaseModel
 from moto.core.exceptions import AWSError
-from moto.ec2 import ec2_backends
+from moto.core.utils import BackendDict
 from moto import settings
 
 from .utils import make_arn_for_certificate
@@ -405,7 +405,7 @@ class CertBundle(BaseModel):
 
 class AWSCertificateManagerBackend(BaseBackend):
     def __init__(self, region):
-        super(AWSCertificateManagerBackend, self).__init__()
+        super().__init__()
         self.region = region
         self._certificates = {}
         self._idempotency_tokens = {}
@@ -559,6 +559,4 @@ class AWSCertificateManagerBackend(BaseBackend):
         return certificate, certificate_chain, private_key
 
 
-acm_backends = {}
-for region, ec2_backend in ec2_backends.items():
-    acm_backends[region] = AWSCertificateManagerBackend(region)
+acm_backends = BackendDict(AWSCertificateManagerBackend, "ec2")
