@@ -7,6 +7,7 @@ import logging
 import docker
 import threading
 import dateutil.parser
+from sys import platform
 
 from moto.core import BaseBackend, BaseModel, CloudFormationModel
 from moto.iam import iam_backends
@@ -27,6 +28,7 @@ from moto.iam.exceptions import IAMNotFoundException
 from moto.core import ACCOUNT_ID as DEFAULT_ACCOUNT_ID
 from moto.core.utils import unix_time_millis, BackendDict
 from moto.utilities.docker_utilities import DockerModel
+from moto import settings
 from ..utilities.tagging_service import TaggingService
 
 logger = logging.getLogger(__name__)
@@ -264,18 +266,20 @@ class JobDefinition(CloudFormationModel):
         )
 
         if required_resource:
-            return required_resource[0]["value"]
+            if req_type == "vcpus":
+                return float(required_resource[0]["value"])
+            elif req_type == "memory":
+                return int(required_resource[0]["value"])
+            else:
+                return required_resource[0]["value"]
         else:
             return self.container_properties.get(req_type, default)
 
     def _validate(self):
+        # For future use when containers arnt the only thing in batch
         if self.type not in ("container",):
             raise ClientException('type must be one of "container"')
 
-        # For future use when containers arnt the only thing in batch
-        if self.type != "container":
-            raise NotImplementedError()
-
         if not isinstance(self.parameters, dict):
             raise ClientException("parameters must be a string to string map")
 
@@ -291,7 +295,7 @@ class JobDefinition(CloudFormationModel):
         vcpus = self._get_resource_requirement("vcpus")
         if vcpus is None:
             raise ClientException("containerProperties must contain vcpus")
-        if vcpus < 1:
+        if vcpus <= 0:
             raise ClientException("container vcpus limit must be greater than 0")
 
     def update(
@@ -415,6 +419,7 @@ class Job(threading.Thread, BaseModel, DockerModel):
         self.all_jobs = all_jobs
 
         self.stop = False
+        self.exit_code = None
 
         self.daemon = True
         self.name = "MOTO-BATCH-" + self.job_id
@@ -422,18 +427,28 @@ class Job(threading.Thread, BaseModel, DockerModel):
         self._log_backend = log_backend
         self.log_stream_name = None
 
-    def describe(self):
+    def describe_short(self):
         result = {
-            "jobDefinition": self.job_definition.arn,
             "jobId": self.job_id,
             "jobName": self.job_name,
-            "jobQueue": self.job_queue.arn,
-            "status": self.job_state,
-            "dependsOn": self.depends_on if self.depends_on else [],
             "createdAt": datetime2int_milliseconds(self.job_created_at),
+            "status": self.job_state,
+            "jobDefinition": self.job_definition.arn,
         }
+        if self.job_stopped_reason is not None:
+            result["statusReason"] = self.job_stopped_reason
         if result["status"] not in ["SUBMITTED", "PENDING", "RUNNABLE", "STARTING"]:
             result["startedAt"] = datetime2int_milliseconds(self.job_started_at)
+        if self.job_stopped:
+            result["stoppedAt"] = datetime2int_milliseconds(self.job_stopped_at)
+            if self.exit_code is not None:
+                result["container"] = {"exitCode": self.exit_code}
+        return result
+
+    def describe(self):
+        result = self.describe_short()
+        result["jobQueue"] = self.job_queue.arn
+        result["dependsOn"] = self.depends_on if self.depends_on else []
         if self.job_stopped:
             result["stoppedAt"] = datetime2int_milliseconds(self.job_stopped_at)
             result["container"] = {}
@@ -452,8 +467,6 @@ class Job(threading.Thread, BaseModel, DockerModel):
                 "environment", []
             )
             result["container"]["logStreamName"] = self.log_stream_name
-        if self.job_stopped_reason is not None:
-            result["statusReason"] = self.job_stopped_reason
         if self.timeout:
             result["timeout"] = self.timeout
         return result
@@ -544,6 +557,28 @@ class Job(threading.Thread, BaseModel, DockerModel):
 
             self.job_started_at = datetime.datetime.now()
 
+            # add host.docker.internal host on linux to emulate Mac + Windows behavior
+            #   for communication with other mock AWS services running on localhost
+            extra_hosts = (
+                {"host.docker.internal": "host-gateway",}
+                if platform == "linux" or platform == "linux2"
+                else {}
+            )
+
+            environment["MOTO_HOST"] = settings.moto_server_host()
+            environment["MOTO_PORT"] = settings.moto_server_port()
+            environment[
+                "MOTO_HTTP_ENDPOINT"
+            ] = f'{environment["MOTO_HOST"]}:{environment["MOTO_PORT"]}'
+
+            run_kwargs = dict()
+            network_name = settings.moto_network_name()
+            network_mode = settings.moto_network_mode()
+            if network_name:
+                run_kwargs["network"] = network_name
+            elif network_mode:
+                run_kwargs["network_mode"] = network_mode
+
             log_config = docker.types.LogConfig(type=docker.types.LogConfig.types.JSON)
             self.job_state = "STARTING"
             container = self.docker_client.containers.run(
@@ -555,6 +590,8 @@ class Job(threading.Thread, BaseModel, DockerModel):
                 environment=environment,
                 mounts=mounts,
                 privileged=privileged,
+                extra_hosts=extra_hosts,
+                **run_kwargs,
             )
             self.job_state = "RUNNING"
             try:
@@ -630,7 +667,8 @@ class Job(threading.Thread, BaseModel, DockerModel):
                 self._log_backend.put_log_events(log_group, stream_name, logs, None)
 
                 result = container.wait() or {}
-                job_failed = self.stop or result.get("StatusCode", 0) > 0
+                self.exit_code = result.get("StatusCode", 0)
+                job_failed = self.stop or self.exit_code > 0
                 self._mark_stopped(success=not job_failed)
 
             except Exception as err:
