@@ -156,7 +156,7 @@ class SAMLProvider(BaseModel):
 
 
 class OpenIDConnectProvider(BaseModel):
-    def __init__(self, url, thumbprint_list, client_id_list=None):
+    def __init__(self, url, thumbprint_list, client_id_list=None, tags=None):
         self._errors = []
         self._validate(url, thumbprint_list, client_id_list)
 
@@ -165,6 +165,7 @@ class OpenIDConnectProvider(BaseModel):
         self.thumbprint_list = thumbprint_list
         self.client_id_list = client_id_list
         self.create_date = datetime.utcnow()
+        self.tags = tags
 
     @property
     def arn(self):
@@ -238,6 +239,9 @@ class OpenIDConnectProvider(BaseModel):
                 )
             )
 
+    def get_tags(self):
+        return [self.tags[tag] for tag in self.tags]
+
 
 class PolicyVersion(object):
     def __init__(
@@ -613,12 +617,12 @@ class Role(CloudFormationModel):
     def delete_from_cloudformation_json(
         cls, resource_name, cloudformation_json, region_name
     ):
-        for profile_name, profile in iam_backend.instance_profiles.items():
+        for profile in iam_backend.instance_profiles.values():
             profile.delete_role(role_name=resource_name)
 
-        for _, role in iam_backend.roles.items():
+        for role in iam_backend.roles.values():
             if role.name == resource_name:
-                for arn, policy in role.policies.items():
+                for arn in role.policies.keys():
                     role.delete_policy(arn)
         iam_backend.delete_role(resource_name)
 
@@ -641,7 +645,7 @@ class Role(CloudFormationModel):
 
         _instance_profiles = []
         for key, instance_profile in iam_backend.instance_profiles.items():
-            for role in instance_profile.roles:
+            for _ in instance_profile.roles:
                 _instance_profiles.append(instance_profile.to_embedded_config_dict())
                 break
 
@@ -848,8 +852,8 @@ class Certificate(BaseModel):
 
 
 class SigningCertificate(BaseModel):
-    def __init__(self, id, user_name, body):
-        self.id = id
+    def __init__(self, certificate_id, user_name, body):
+        self.id = certificate_id
         self.user_name = user_name
         self.body = body
         self.upload_date = datetime.utcnow()
@@ -1522,7 +1526,7 @@ class IAMBackend(BaseBackend):
         self.access_keys = {}
 
         self.tagger = TaggingService()
-        super(IAMBackend, self).__init__()
+        super().__init__()
 
     def _init_managed_policies(self):
         return dict((p.arn, p) for p in aws_managed_policies)
@@ -1574,6 +1578,8 @@ class IAMBackend(BaseBackend):
             policy = arns[policy_arn]
         except KeyError:
             raise IAMNotFoundException("Policy {0} was not found.".format(policy_arn))
+        if policy.arn in self.get_group(group_name).managed_policies.keys():
+            return
         policy.attach_to(self.get_group(group_name))
 
     def detach_group_policy(self, policy_arn, group_name):
@@ -1658,8 +1664,6 @@ class IAMBackend(BaseBackend):
         return self._filter_attached_policies(policies, marker, max_items, path_prefix)
 
     def set_default_policy_version(self, policy_arn, version_id):
-        import re
-
         if re.match(r"v[1-9][0-9]*(\.[A-Za-z0-9-]*)?", version_id) is None:
             raise ValidationError(
                 "Value '{0}' at 'versionId' failed to satisfy constraint: Member must satisfy regular expression pattern: v[1-9][0-9]*(\\.[A-Za-z0-9-]*)?".format(
@@ -2042,7 +2046,7 @@ class IAMBackend(BaseBackend):
         return cert
 
     def get_server_certificate(self, name):
-        for key, cert in self.certificates.items():
+        for cert in self.certificates.values():
             if name == cert.cert_name:
                 return cert
 
@@ -2073,14 +2077,11 @@ class IAMBackend(BaseBackend):
         return group
 
     def get_group(self, group_name, marker=None, max_items=None):
-        group = None
         try:
-            group = self.groups[group_name]
+            return self.groups[group_name]
         except KeyError:
             raise IAMNotFoundException("Group {0} not found".format(group_name))
 
-        return group
-
     def list_groups(self):
         return self.groups.values()
 
@@ -2120,6 +2121,29 @@ class IAMBackend(BaseBackend):
                 "The group with name {0} cannot be found.".format(group_name)
             )
 
+    def update_group(self, group_name, new_group_name, new_path):
+        if new_group_name:
+            if new_group_name in self.groups:
+                raise IAMConflictException(
+                    message="Group {0} already exists".format(new_group_name)
+                )
+            try:
+                group = self.groups[group_name]
+            except KeyError:
+                raise IAMNotFoundException(
+                    "The group with name {0} cannot be found.".format(group_name)
+                )
+
+            existing_policies = group.managed_policies.copy()
+            for policy_arn in existing_policies:
+                self.detach_group_policy(policy_arn, group_name)
+            if new_path:
+                group.path = new_path
+            group.name = new_group_name
+            self.groups[new_group_name] = self.groups.pop(group_name)
+            for policy_arn in existing_policies:
+                self.attach_group_policy(policy_arn, new_group_name)
+
     def create_user(self, user_name, path="/", tags=None):
         if user_name in self.users:
             raise IAMConflictException(
@@ -2530,12 +2554,12 @@ class IAMBackend(BaseBackend):
     def delete_account_alias(self, alias):
         self.account_aliases = []
 
-    def get_account_authorization_details(self, filter):
+    def get_account_authorization_details(self, policy_filter):
         policies = self.managed_policies.values()
         local_policies = set(policies) - set(aws_managed_policies)
         returned_policies = []
 
-        if len(filter) == 0:
+        if len(policy_filter) == 0:
             return {
                 "instance_profiles": self.instance_profiles.values(),
                 "roles": self.roles.values(),
@@ -2544,16 +2568,16 @@ class IAMBackend(BaseBackend):
                 "managed_policies": self.managed_policies.values(),
             }
 
-        if "AWSManagedPolicy" in filter:
+        if "AWSManagedPolicy" in policy_filter:
             returned_policies = aws_managed_policies
-        if "LocalManagedPolicy" in filter:
+        if "LocalManagedPolicy" in policy_filter:
             returned_policies = returned_policies + list(local_policies)
 
         return {
             "instance_profiles": self.instance_profiles.values(),
-            "roles": self.roles.values() if "Role" in filter else [],
-            "groups": self.groups.values() if "Group" in filter else [],
-            "users": self.users.values() if "User" in filter else [],
+            "roles": self.roles.values() if "Role" in policy_filter else [],
+            "groups": self.groups.values() if "Group" in policy_filter else [],
+            "users": self.users.values() if "User" in policy_filter else [],
             "managed_policies": returned_policies,
         }
 
@@ -2596,8 +2620,13 @@ class IAMBackend(BaseBackend):
                     return user
         return None
 
-    def create_open_id_connect_provider(self, url, thumbprint_list, client_id_list):
-        open_id_provider = OpenIDConnectProvider(url, thumbprint_list, client_id_list)
+    def create_open_id_connect_provider(
+        self, url, thumbprint_list, client_id_list, tags
+    ):
+        clean_tags = self._tag_verification(tags)
+        open_id_provider = OpenIDConnectProvider(
+            url, thumbprint_list, client_id_list, clean_tags
+        )
 
         if open_id_provider.arn in self.open_id_providers:
             raise EntityAlreadyExists("Unknown")
@@ -2605,6 +2634,40 @@ class IAMBackend(BaseBackend):
         self.open_id_providers[open_id_provider.arn] = open_id_provider
         return open_id_provider
 
+    def update_open_id_connect_provider_thumbprint(self, arn, thumbprint_list):
+        open_id_provider = self.get_open_id_connect_provider(arn)
+        open_id_provider.thumbprint_list = thumbprint_list
+
+    def tag_open_id_connect_provider(self, arn, tags):
+        open_id_provider = self.get_open_id_connect_provider(arn)
+        clean_tags = self._tag_verification(tags)
+        open_id_provider.tags.update(clean_tags)
+
+    def untag_open_id_connect_provider(self, arn, tag_keys):
+        open_id_provider = self.get_open_id_connect_provider(arn)
+
+        for key in tag_keys:
+            ref_key = key.lower()
+            self._validate_tag_key(key, exception_param="tagKeys")
+            open_id_provider.tags.pop(ref_key, None)
+
+    def list_open_id_connect_provider_tags(self, arn, marker, max_items=100):
+        open_id_provider = self.get_open_id_connect_provider(arn)
+
+        max_items = int(max_items)
+        tag_index = sorted(open_id_provider.tags)
+        start_idx = int(marker) if marker else 0
+
+        tag_index = tag_index[start_idx : start_idx + max_items]
+
+        if len(open_id_provider.tags) <= (start_idx + max_items):
+            marker = None
+        else:
+            marker = str(start_idx + max_items)
+
+        tags = [open_id_provider.tags[tag] for tag in tag_index]
+        return tags, marker
+
     def delete_open_id_connect_provider(self, arn):
         self.open_id_providers.pop(arn, None)
 
