@@ -4,7 +4,7 @@ from werkzeug.exceptions import BadRequest
 
 class RedshiftClientError(BadRequest):
     def __init__(self, code, message):
-        super(RedshiftClientError, self).__init__()
+        super().__init__()
         self.description = json.dumps(
             {
                 "Error": {"Code": code, "Message": message, "Type": "Sender"},
@@ -15,14 +15,14 @@ class RedshiftClientError(BadRequest):
 
 class ClusterNotFoundError(RedshiftClientError):
     def __init__(self, cluster_identifier):
-        super(ClusterNotFoundError, self).__init__(
+        super().__init__(
             "ClusterNotFound", "Cluster {0} not found.".format(cluster_identifier)
         )
 
 
 class ClusterSubnetGroupNotFoundError(RedshiftClientError):
     def __init__(self, subnet_identifier):
-        super(ClusterSubnetGroupNotFoundError, self).__init__(
+        super().__init__(
             "ClusterSubnetGroupNotFound",
             "Subnet group {0} not found.".format(subnet_identifier),
         )
@@ -30,7 +30,7 @@ class ClusterSubnetGroupNotFoundError(RedshiftClientError):
 
 class ClusterSecurityGroupNotFoundError(RedshiftClientError):
     def __init__(self, group_identifier):
-        super(ClusterSecurityGroupNotFoundError, self).__init__(
+        super().__init__(
             "ClusterSecurityGroupNotFound",
             "Security group {0} not found.".format(group_identifier),
         )
@@ -38,7 +38,7 @@ class ClusterSecurityGroupNotFoundError(RedshiftClientError):
 
 class ClusterParameterGroupNotFoundError(RedshiftClientError):
     def __init__(self, group_identifier):
-        super(ClusterParameterGroupNotFoundError, self).__init__(
+        super().__init__(
             "ClusterParameterGroupNotFound",
             "Parameter group {0} not found.".format(group_identifier),
         )
@@ -46,14 +46,14 @@ class ClusterParameterGroupNotFoundError(RedshiftClientError):
 
 class InvalidSubnetError(RedshiftClientError):
     def __init__(self, subnet_identifier):
-        super(InvalidSubnetError, self).__init__(
+        super().__init__(
             "InvalidSubnet", "Subnet {0} not found.".format(subnet_identifier)
         )
 
 
 class SnapshotCopyGrantAlreadyExistsFaultError(RedshiftClientError):
     def __init__(self, snapshot_copy_grant_name):
-        super(SnapshotCopyGrantAlreadyExistsFaultError, self).__init__(
+        super().__init__(
             "SnapshotCopyGrantAlreadyExistsFault",
             "Cannot create the snapshot copy grant because a grant "
             "with the identifier '{0}' already exists".format(snapshot_copy_grant_name),
@@ -62,7 +62,7 @@ class SnapshotCopyGrantAlreadyExistsFaultError(RedshiftClientError):
 
 class SnapshotCopyGrantNotFoundFaultError(RedshiftClientError):
     def __init__(self, snapshot_copy_grant_name):
-        super(SnapshotCopyGrantNotFoundFaultError, self).__init__(
+        super().__init__(
             "SnapshotCopyGrantNotFoundFault",
             "Snapshot copy grant not found: {0}".format(snapshot_copy_grant_name),
         )
@@ -70,7 +70,7 @@ class SnapshotCopyGrantNotFoundFaultError(RedshiftClientError):
 
 class ClusterSnapshotNotFoundError(RedshiftClientError):
     def __init__(self, snapshot_identifier):
-        super(ClusterSnapshotNotFoundError, self).__init__(
+        super().__init__(
             "ClusterSnapshotNotFound",
             "Snapshot {0} not found.".format(snapshot_identifier),
         )
@@ -78,7 +78,7 @@ class ClusterSnapshotNotFoundError(RedshiftClientError):
 
 class ClusterSnapshotAlreadyExistsError(RedshiftClientError):
     def __init__(self, snapshot_identifier):
-        super(ClusterSnapshotAlreadyExistsError, self).__init__(
+        super().__init__(
             "ClusterSnapshotAlreadyExists",
             "Cannot create the snapshot because a snapshot with the "
             "identifier {0} already exists".format(snapshot_identifier),
@@ -87,9 +87,7 @@ class ClusterSnapshotAlreadyExistsError(RedshiftClientError):
 
 class InvalidParameterValueError(RedshiftClientError):
     def __init__(self, message):
-        super(InvalidParameterValueError, self).__init__(
-            "InvalidParameterValue", message
-        )
+        super().__init__("InvalidParameterValue", message)
 
 
 class ResourceNotFoundFaultError(RedshiftClientError):
@@ -103,12 +101,12 @@ class ResourceNotFoundFaultError(RedshiftClientError):
             msg = "{0} ({1}) not found.".format(resource_type, resource_name)
         if message:
             msg = message
-        super(ResourceNotFoundFaultError, self).__init__("ResourceNotFoundFault", msg)
+        super().__init__("ResourceNotFoundFault", msg)
 
 
 class SnapshotCopyDisabledFaultError(RedshiftClientError):
     def __init__(self, cluster_identifier):
-        super(SnapshotCopyDisabledFaultError, self).__init__(
+        super().__init__(
             "SnapshotCopyDisabledFault",
             "Cannot modify retention period because snapshot copy is disabled on Cluster {0}.".format(
                 cluster_identifier
@@ -118,7 +116,7 @@ class SnapshotCopyDisabledFaultError(RedshiftClientError):
 
 class SnapshotCopyAlreadyDisabledFaultError(RedshiftClientError):
     def __init__(self, cluster_identifier):
-        super(SnapshotCopyAlreadyDisabledFaultError, self).__init__(
+        super().__init__(
             "SnapshotCopyAlreadyDisabledFault",
             "Snapshot Copy is already disabled on Cluster {0}.".format(
                 cluster_identifier
@@ -128,7 +126,7 @@ class SnapshotCopyAlreadyDisabledFaultError(RedshiftClientError):
 
 class SnapshotCopyAlreadyEnabledFaultError(RedshiftClientError):
     def __init__(self, cluster_identifier):
-        super(SnapshotCopyAlreadyEnabledFaultError, self).__init__(
+        super().__init__(
             "SnapshotCopyAlreadyEnabledFault",
             "Snapshot Copy is already enabled on Cluster {0}.".format(
                 cluster_identifier
@@ -138,28 +136,22 @@ class SnapshotCopyAlreadyEnabledFaultError(RedshiftClientError):
 
 class ClusterAlreadyExistsFaultError(RedshiftClientError):
     def __init__(self):
-        super(ClusterAlreadyExistsFaultError, self).__init__(
-            "ClusterAlreadyExists", "Cluster already exists"
-        )
+        super().__init__("ClusterAlreadyExists", "Cluster already exists")
 
 
 class InvalidParameterCombinationError(RedshiftClientError):
     def __init__(self, message):
-        super(InvalidParameterCombinationError, self).__init__(
-            "InvalidParameterCombination", message
-        )
+        super().__init__("InvalidParameterCombination", message)
 
 
 class UnknownSnapshotCopyRegionFaultError(RedshiftClientError):
     def __init__(self, message):
-        super(UnknownSnapshotCopyRegionFaultError, self).__init__(
-            "UnknownSnapshotCopyRegionFault", message
-        )
+        super().__init__("UnknownSnapshotCopyRegionFault", message)
 
 
 class ClusterSecurityGroupNotFoundFaultError(RedshiftClientError):
     def __init__(self):
-        super(ClusterSecurityGroupNotFoundFaultError, self).__init__(
+        super().__init__(
             "ClusterSecurityGroupNotFoundFault",
             "The cluster security group name does not refer to an existing cluster security group.",
         )
