@@ -59,7 +59,7 @@ class RedshiftResponse(BaseResponse):
             return xml
 
     def call_action(self):
-        status, headers, body = super(RedshiftResponse, self).call_action()
+        status, headers, body = super().call_action()
         if status >= 400 and not self.request_json:
             body = convert_json_error_to_xml(body)
         return status, headers, body
@@ -159,8 +159,38 @@ class RedshiftResponse(BaseResponse):
             }
         )
 
+    def pause_cluster(self):
+        cluster_id = self._get_param("ClusterIdentifier")
+        cluster = self.redshift_backend.pause_cluster(cluster_id).to_json()
+        return self.get_response(
+            {
+                "PauseClusterResponse": {
+                    "PauseClusterResult": {"Cluster": cluster},
+                    "ResponseMetadata": {
+                        "RequestId": "384ac68d-3775-11df-8963-01868b7c937a"
+                    },
+                }
+            }
+        )
+
+    def resume_cluster(self):
+        cluster_id = self._get_param("ClusterIdentifier")
+        cluster = self.redshift_backend.resume_cluster(cluster_id).to_json()
+        return self.get_response(
+            {
+                "ResumeClusterResponse": {
+                    "ResumeClusterResult": {"Cluster": cluster},
+                    "ResponseMetadata": {
+                        "RequestId": "384ac68d-3775-11df-8963-01868b7c937a"
+                    },
+                }
+            }
+        )
+
     def restore_from_cluster_snapshot(self):
         enhanced_vpc_routing = self._get_bool_param("EnhancedVpcRouting")
+        node_type = self._get_param("NodeType")
+        number_of_nodes = self._get_int_param("NumberOfNodes")
         restore_kwargs = {
             "snapshot_identifier": self._get_param("SnapshotIdentifier"),
             "cluster_identifier": self._get_param("ClusterIdentifier"),
@@ -185,6 +215,10 @@ class RedshiftResponse(BaseResponse):
         }
         if enhanced_vpc_routing is not None:
             restore_kwargs["enhanced_vpc_routing"] = enhanced_vpc_routing
+        if node_type is not None:
+            restore_kwargs["node_type"] = node_type
+        if number_of_nodes is not None:
+            restore_kwargs["number_of_nodes"] = number_of_nodes
         cluster = self.redshift_backend.restore_from_cluster_snapshot(
             **restore_kwargs
         ).to_json()
