@@ -15,7 +15,7 @@ from moto.route53.exceptions import (
     NoSuchQueryLoggingConfig,
     QueryLoggingConfigAlreadyExists,
 )
-from moto.core import BaseBackend, BaseModel, CloudFormationModel
+from moto.core import BaseBackend, BaseModel, CloudFormationModel, ACCOUNT_ID
 from moto.utilities.paginator import paginate
 from .utils import PAGINATION_MODEL
 
@@ -212,11 +212,17 @@ def reverse_domain_name(domain_name):
 
 
 class FakeZone(CloudFormationModel):
-    def __init__(self, name, id_, private_zone, comment=None):
+    def __init__(
+        self, name, id_, private_zone, vpcid=None, vpcregion=None, comment=None
+    ):
         self.name = name
         self.id = id_
         if comment is not None:
             self.comment = comment
+        if vpcid is not None:
+            self.vpcid = vpcid
+        if vpcregion is not None:
+            self.vpcregion = vpcregion
         self.private_zone = private_zone
         self.rrsets = []
 
@@ -365,9 +371,18 @@ class Route53Backend(BaseBackend):
         self.resource_tags = defaultdict(dict)
         self.query_logging_configs = {}
 
-    def create_hosted_zone(self, name, private_zone, comment=None):
+    def create_hosted_zone(
+        self, name, private_zone, vpcid=None, vpcregion=None, comment=None
+    ):
         new_id = create_route53_zone_id()
-        new_zone = FakeZone(name, new_id, private_zone=private_zone, comment=comment)
+        new_zone = FakeZone(
+            name,
+            new_id,
+            private_zone=private_zone,
+            vpcid=vpcid,
+            vpcregion=vpcregion,
+            comment=comment,
+        )
         self.zones[new_id] = new_zone
         return new_zone
 
@@ -459,6 +474,24 @@ class Route53Backend(BaseBackend):
             zones = sorted(zones, key=sort_key)
         return dnsname, zones
 
+    def list_hosted_zones_by_vpc(self, VPCId, VPCRegion, MaxItems=None, NextToken=None):
+
+        zone_list = []
+        for zone in self.list_hosted_zones():
+            if zone.private_zone == "true":
+                this_zone = self.get_hosted_zone(zone.id)
+                if this_zone.vpcid == VPCId:
+                    this_id = f"/hostedzone/{zone.id}"
+                    zone_list.append(
+                        {
+                            "HostedZoneId": this_id,
+                            "Name": zone.name,
+                            "Owner": {"OwningAccount": ACCOUNT_ID},
+                        }
+                    )
+
+        return zone_list
+
     def get_hosted_zone(self, id_):
         the_zone = self.zones.get(id_.replace("/hostedzone/", ""))
         if not the_zone:
