@@ -30,32 +30,39 @@ class Route53(BaseResponse):
     def list_or_create_hostzone_response(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
 
+        # Set these here outside the scope of the try/except
+        # so they're defined later when we call create_hosted_zone()
+        vpcid = None
+        vpcregion = None
         if request.method == "POST":
             elements = xmltodict.parse(self.body)
-            if "HostedZoneConfig" in elements["CreateHostedZoneRequest"]:
-                comment = elements["CreateHostedZoneRequest"]["HostedZoneConfig"][
-                    "Comment"
-                ]
-                try:
-                    # in boto3, this field is set directly in the xml
-                    private_zone = elements["CreateHostedZoneRequest"][
-                        "HostedZoneConfig"
-                    ]["PrivateZone"]
-                except KeyError:
-                    # if a VPC subsection is only included in xmls params when private_zone=True,
-                    # see boto: boto/route53/connection.py
-                    private_zone = "VPC" in elements["CreateHostedZoneRequest"]
+            zone_request = elements["CreateHostedZoneRequest"]
+            if "HostedZoneConfig" in zone_request:
+                zone_config = zone_request["HostedZoneConfig"]
+                comment = zone_config["Comment"]
+                private_zone = zone_config.get("PrivateZone", False)
             else:
                 comment = None
                 private_zone = False
 
-            name = elements["CreateHostedZoneRequest"]["Name"]
+            # It is possible to create a Private Hosted Zone without
+            # associating VPC at the time of creation.
+            if private_zone == "true":
+                if zone_request.get("VPC", None) is not None:
+                    vpcid = zone_request["VPC"].get("VPCId", None)
+                    vpcregion = zone_request["VPC"].get("VPCRegion", None)
+
+            name = zone_request["Name"]
 
             if name[-1] != ".":
                 name += "."
 
             new_zone = route53_backend.create_hosted_zone(
-                name, comment=comment, private_zone=private_zone
+                name,
+                comment=comment,
+                private_zone=private_zone,
+                vpcid=vpcid,
+                vpcregion=vpcregion,
             )
             template = Template(CREATE_HOSTED_ZONE_RESPONSE)
             return 201, headers, template.render(zone=new_zone)
@@ -76,6 +83,16 @@ class Route53(BaseResponse):
         template = Template(LIST_HOSTED_ZONES_BY_NAME_RESPONSE)
         return 200, headers, template.render(zones=zones, dnsname=dnsname, xmlns=XMLNS)
 
+    def list_hosted_zones_by_vpc_response(self, request, full_url, headers):
+        self.setup_class(request, full_url, headers)
+        parsed_url = urlparse(full_url)
+        query_params = parse_qs(parsed_url.query)
+        vpc_id = query_params.get("vpcid")[0]
+        vpc_region = query_params.get("vpcregion")[0]
+        zones = route53_backend.list_hosted_zones_by_vpc(vpc_id, vpc_region)
+        template = Template(LIST_HOSTED_ZONES_BY_VPC_RESPONSE)
+        return 200, headers, template.render(zones=zones, xmlns=XMLNS)
+
     @error_handler
     def get_or_delete_hostzone_response(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
@@ -414,6 +431,13 @@ GET_HOSTED_ZONE_RESPONSE = """<GetHostedZoneResponse xmlns="https://route53.amaz
          <NameServer>moto.test.com</NameServer>
       </NameServers>
    </DelegationSet>
+   <VPCs>
+      <VPC>
+         <VPCId>{{zone.vpcid}}</VPCId>
+         <VPCRegion>{{zone.vpcregion}}</VPCRegion>
+      </VPC>
+   </VPCs>
+
 </GetHostedZoneResponse>"""
 
 CREATE_HOSTED_ZONE_RESPONSE = """<CreateHostedZoneResponse xmlns="https://route53.amazonaws.com/doc/2012-12-12/">
@@ -433,6 +457,10 @@ CREATE_HOSTED_ZONE_RESPONSE = """<CreateHostedZoneResponse xmlns="https://route5
          <NameServer>moto.test.com</NameServer>
       </NameServers>
    </DelegationSet>
+   <VPC>
+      <VPCId>{{zone.vpcid}}</VPCId>
+      <VPCRegion>{{zone.vpcregion}}</VPCRegion>
+   </VPC>
 </CreateHostedZoneResponse>"""
 
 LIST_HOSTED_ZONES_RESPONSE = """<ListHostedZonesResponse xmlns="https://route53.amazonaws.com/doc/2012-12-12/">
@@ -476,6 +504,25 @@ LIST_HOSTED_ZONES_BY_NAME_RESPONSE = """<ListHostedZonesByNameResponse xmlns="{{
    <IsTruncated>false</IsTruncated>
 </ListHostedZonesByNameResponse>"""
 
+LIST_HOSTED_ZONES_BY_VPC_RESPONSE = """<ListHostedZonesByVpcResponse xmlns="{{xmlns}}">
+   <HostedZoneSummaries>
+       {% for zone in zones -%}
+       <HostedZoneSummary>
+           <HostedZoneId>{{zone["HostedZoneId"]}}</HostedZoneId>
+           <Name>{{zone["Name"]}}</Name>
+           <Owner>
+               {% if zone["Owner"]["OwningAccount"] -%}
+               <OwningAccount>{{zone["Owner"]["OwningAccount"]}}</OwningAccount>
+               {% endif -%}
+               {% if zone["Owner"]["OwningService"] -%}
+               <OwningService>zone["Owner"]["OwningService"]</OwningService>
+               {% endif -%}
+           </Owner>
+       </HostedZoneSummary>
+       {% endfor -%}
+   </HostedZoneSummaries>
+</ListHostedZonesByVpcResponse>"""
+
 CREATE_HEALTH_CHECK_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
 <CreateHealthCheckResponse xmlns="{{ xmlns }}">
   {{ health_check.to_xml() }}
