@@ -5,7 +5,7 @@ ERROR_WITH_BUCKET_NAME = """{% extends 'single_error' %}
 """
 
 ERROR_WITH_KEY_NAME = """{% extends 'single_error' %}
-{% block extra %}<KeyName>{{ key_name }}</KeyName>{% endblock %}
+{% block extra %}<Key>{{ key }}</Key>{% endblock %}
 """
 
 ERROR_WITH_ARGUMENT = """{% extends 'single_error' %}
@@ -38,7 +38,7 @@ class S3ClientError(RESTError):
     def __init__(self, *args, **kwargs):
         kwargs.setdefault("template", "single_error")
         self.templates["bucket_error"] = ERROR_WITH_BUCKET_NAME
-        super(S3ClientError, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class InvalidArgumentError(S3ClientError):
@@ -49,16 +49,14 @@ class InvalidArgumentError(S3ClientError):
         kwargs["name"] = name
         kwargs["value"] = value
         self.templates["argument_error"] = ERROR_WITH_ARGUMENT
-        super(InvalidArgumentError, self).__init__(
-            "InvalidArgument", message, *args, **kwargs
-        )
+        super().__init__("InvalidArgument", message, *args, **kwargs)
 
 
 class BucketError(S3ClientError):
     def __init__(self, *args, **kwargs):
         kwargs.setdefault("template", "bucket_error")
         self.templates["bucket_error"] = ERROR_WITH_BUCKET_NAME
-        super(BucketError, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class BucketAlreadyExists(BucketError):
@@ -67,7 +65,7 @@ class BucketAlreadyExists(BucketError):
     def __init__(self, *args, **kwargs):
         kwargs.setdefault("template", "bucket_error")
         self.templates["bucket_error"] = ERROR_WITH_BUCKET_NAME
-        super(BucketAlreadyExists, self).__init__(
+        super().__init__(
             "BucketAlreadyExists",
             (
                 "The requested bucket name is not available. The bucket "
@@ -83,7 +81,7 @@ class MissingBucket(BucketError):
     code = 404
 
     def __init__(self, *args, **kwargs):
-        super(MissingBucket, self).__init__(
+        super().__init__(
             "NoSuchBucket", "The specified bucket does not exist", *args, **kwargs
         )
 
@@ -91,17 +89,17 @@ class MissingBucket(BucketError):
 class MissingKey(S3ClientError):
     code = 404
 
-    def __init__(self, key_name):
-        super(MissingKey, self).__init__(
-            "NoSuchKey", "The specified key does not exist.", Key=key_name
-        )
+    def __init__(self, **kwargs):
+        kwargs.setdefault("template", "key_error")
+        self.templates["key_error"] = ERROR_WITH_KEY_NAME
+        super().__init__("NoSuchKey", "The specified key does not exist.", **kwargs)
 
 
 class MissingVersion(S3ClientError):
     code = 404
 
     def __init__(self, *args, **kwargs):
-        super(MissingVersion, self).__init__(
+        super().__init__(
             "NoSuchVersion", "The specified version does not exist.", *args, **kwargs
         )
 
@@ -114,7 +112,7 @@ class InvalidVersion(S3ClientError):
         kwargs["name"] = "versionId"
         kwargs["value"] = version_id
         self.templates["argument_error"] = ERROR_WITH_ARGUMENT
-        super(InvalidVersion, self).__init__(
+        super().__init__(
             "InvalidArgument", "Invalid version id specified", *args, **kwargs
         )
 
@@ -123,7 +121,7 @@ class ObjectNotInActiveTierError(S3ClientError):
     code = 403
 
     def __init__(self, key_name):
-        super(ObjectNotInActiveTierError, self).__init__(
+        super().__init__(
             "ObjectNotInActiveTierError",
             "The source object of the COPY operation is not in the active tier and is only stored in Amazon Glacier.",
             Key=key_name,
@@ -134,7 +132,7 @@ class InvalidPartOrder(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidPartOrder, self).__init__(
+        super().__init__(
             "InvalidPartOrder",
             (
                 "The list of parts was not in ascending order. The parts "
@@ -149,7 +147,7 @@ class InvalidPart(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidPart, self).__init__(
+        super().__init__(
             "InvalidPart",
             (
                 "One or more of the specified parts could not be found. "
@@ -165,7 +163,7 @@ class EntityTooSmall(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(EntityTooSmall, self).__init__(
+        super().__init__(
             "EntityTooSmall",
             "Your proposed upload is smaller than the minimum allowed object size.",
             *args,
@@ -177,7 +175,7 @@ class InvalidRequest(S3ClientError):
     code = 400
 
     def __init__(self, method, *args, **kwargs):
-        super(InvalidRequest, self).__init__(
+        super().__init__(
             "InvalidRequest",
             "Found unsupported HTTP method in CORS config. Unsupported method is {}".format(
                 method
@@ -191,7 +189,7 @@ class IllegalLocationConstraintException(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(IllegalLocationConstraintException, self).__init__(
+        super().__init__(
             "IllegalLocationConstraintException",
             "The unspecified location constraint is incompatible for the region specific endpoint this request was sent to.",
             *args,
@@ -203,7 +201,7 @@ class MalformedXML(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(MalformedXML, self).__init__(
+        super().__init__(
             "MalformedXML",
             "The XML you provided was not well-formed or did not validate against our published schema",
             *args,
@@ -215,7 +213,7 @@ class MalformedACLError(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(MalformedACLError, self).__init__(
+        super().__init__(
             "MalformedACLError",
             "The XML you provided was not well-formed or did not validate against our published schema",
             *args,
@@ -227,16 +225,14 @@ class InvalidTargetBucketForLogging(S3ClientError):
     code = 400
 
     def __init__(self, msg):
-        super(InvalidTargetBucketForLogging, self).__init__(
-            "InvalidTargetBucketForLogging", msg
-        )
+        super().__init__("InvalidTargetBucketForLogging", msg)
 
 
 class CrossLocationLoggingProhibitted(S3ClientError):
     code = 403
 
     def __init__(self):
-        super(CrossLocationLoggingProhibitted, self).__init__(
+        super().__init__(
             "CrossLocationLoggingProhibitted", "Cross S3 location logging not allowed."
         )
 
@@ -248,14 +244,30 @@ class InvalidMaxPartArgument(S3ClientError):
         error = "Argument {} must be an integer between {} and {}".format(
             arg, min_val, max_val
         )
-        super(InvalidMaxPartArgument, self).__init__("InvalidArgument", error)
+        super().__init__("InvalidArgument", error)
+
+
+class InvalidMaxPartNumberArgument(InvalidArgumentError):
+    code = 400
+
+    def __init__(self, value, *args, **kwargs):
+        error = "Part number must be an integer between 1 and 10000, inclusive"
+        super().__init__(message=error, name="partNumber", value=value, *args, **kwargs)
+
+
+class NotAnIntegerException(InvalidArgumentError):
+    code = 400
+
+    def __init__(self, name, value, *args, **kwargs):
+        error = f"Provided {name} not an integer or within integer range"
+        super().__init__(message=error, name=name, value=value, *args, **kwargs)
 
 
 class InvalidNotificationARN(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidNotificationARN, self).__init__(
+        super().__init__(
             "InvalidArgument", "The ARN is not well formed", *args, **kwargs
         )
 
@@ -264,7 +276,7 @@ class InvalidNotificationDestination(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidNotificationDestination, self).__init__(
+        super().__init__(
             "InvalidArgument",
             "The notification destination service region is not valid for the bucket location constraint",
             *args,
@@ -276,7 +288,7 @@ class InvalidNotificationEvent(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidNotificationEvent, self).__init__(
+        super().__init__(
             "InvalidArgument",
             "The event is not supported for notifications",
             *args,
@@ -288,7 +300,7 @@ class InvalidStorageClass(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidStorageClass, self).__init__(
+        super().__init__(
             "InvalidStorageClass",
             "The storage class you specified is not valid",
             *args,
@@ -300,7 +312,7 @@ class InvalidBucketName(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidBucketName, self).__init__(
+        super().__init__(
             "InvalidBucketName", "The specified bucket is not valid.", *args, **kwargs
         )
 
@@ -309,7 +321,7 @@ class DuplicateTagKeys(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(DuplicateTagKeys, self).__init__(
+        super().__init__(
             "InvalidTag",
             "Cannot provide multiple Tags with the same key",
             *args,
@@ -321,25 +333,21 @@ class S3AccessDeniedError(S3ClientError):
     code = 403
 
     def __init__(self, *args, **kwargs):
-        super(S3AccessDeniedError, self).__init__(
-            "AccessDenied", "Access Denied", *args, **kwargs
-        )
+        super().__init__("AccessDenied", "Access Denied", *args, **kwargs)
 
 
 class BucketAccessDeniedError(BucketError):
     code = 403
 
     def __init__(self, *args, **kwargs):
-        super(BucketAccessDeniedError, self).__init__(
-            "AccessDenied", "Access Denied", *args, **kwargs
-        )
+        super().__init__("AccessDenied", "Access Denied", *args, **kwargs)
 
 
 class S3InvalidTokenError(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(S3InvalidTokenError, self).__init__(
+        super().__init__(
             "InvalidToken",
             "The provided token is malformed or otherwise invalid.",
             *args,
@@ -347,11 +355,23 @@ class S3InvalidTokenError(S3ClientError):
         )
 
 
+class S3AclAndGrantError(S3ClientError):
+    code = 400
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(
+            "InvalidRequest",
+            "Specifying both Canned ACLs and Header Grants is not allowed",
+            *args,
+            **kwargs,
+        )
+
+
 class BucketInvalidTokenError(BucketError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(BucketInvalidTokenError, self).__init__(
+        super().__init__(
             "InvalidToken",
             "The provided token is malformed or otherwise invalid.",
             *args,
@@ -363,7 +383,7 @@ class S3InvalidAccessKeyIdError(S3ClientError):
     code = 403
 
     def __init__(self, *args, **kwargs):
-        super(S3InvalidAccessKeyIdError, self).__init__(
+        super().__init__(
             "InvalidAccessKeyId",
             "The AWS Access Key Id you provided does not exist in our records.",
             *args,
@@ -375,7 +395,7 @@ class BucketInvalidAccessKeyIdError(S3ClientError):
     code = 403
 
     def __init__(self, *args, **kwargs):
-        super(BucketInvalidAccessKeyIdError, self).__init__(
+        super().__init__(
             "InvalidAccessKeyId",
             "The AWS Access Key Id you provided does not exist in our records.",
             *args,
@@ -387,7 +407,7 @@ class S3SignatureDoesNotMatchError(S3ClientError):
     code = 403
 
     def __init__(self, *args, **kwargs):
-        super(S3SignatureDoesNotMatchError, self).__init__(
+        super().__init__(
             "SignatureDoesNotMatch",
             "The request signature we calculated does not match the signature you provided. Check your key and signing method.",
             *args,
@@ -399,7 +419,7 @@ class BucketSignatureDoesNotMatchError(S3ClientError):
     code = 403
 
     def __init__(self, *args, **kwargs):
-        super(BucketSignatureDoesNotMatchError, self).__init__(
+        super().__init__(
             "SignatureDoesNotMatch",
             "The request signature we calculated does not match the signature you provided. Check your key and signing method.",
             *args,
@@ -411,7 +431,7 @@ class NoSuchPublicAccessBlockConfiguration(S3ClientError):
     code = 404
 
     def __init__(self, *args, **kwargs):
-        super(NoSuchPublicAccessBlockConfiguration, self).__init__(
+        super().__init__(
             "NoSuchPublicAccessBlockConfiguration",
             "The public access block configuration was not found",
             *args,
@@ -423,7 +443,7 @@ class InvalidPublicAccessBlockConfiguration(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidPublicAccessBlockConfiguration, self).__init__(
+        super().__init__(
             "InvalidRequest",
             "Must specify at least one configuration.",
             *args,
@@ -435,16 +455,14 @@ class WrongPublicAccessBlockAccountIdError(S3ClientError):
     code = 403
 
     def __init__(self):
-        super(WrongPublicAccessBlockAccountIdError, self).__init__(
-            "AccessDenied", "Access Denied"
-        )
+        super().__init__("AccessDenied", "Access Denied")
 
 
 class NoSystemTags(S3ClientError):
     code = 400
 
     def __init__(self):
-        super(NoSystemTags, self).__init__(
+        super().__init__(
             "InvalidTag", "System tags cannot be added/updated by requester"
         )
 
@@ -456,7 +474,7 @@ class NoSuchUpload(S3ClientError):
         kwargs.setdefault("template", "error_uploadid")
         kwargs["upload_id"] = upload_id
         self.templates["error_uploadid"] = ERROR_WITH_UPLOADID
-        super(NoSuchUpload, self).__init__(
+        super().__init__(
             "NoSuchUpload",
             "The specified upload does not exist. The upload ID may be invalid, or the upload may have been aborted or completed.",
             *args,
@@ -470,7 +488,7 @@ class PreconditionFailed(S3ClientError):
     def __init__(self, failed_condition, **kwargs):
         kwargs.setdefault("template", "condition_error")
         self.templates["condition_error"] = ERROR_WITH_CONDITION_NAME
-        super(PreconditionFailed, self).__init__(
+        super().__init__(
             "PreconditionFailed",
             "At least one of the pre-conditions you specified did not hold",
             condition=failed_condition,
@@ -484,7 +502,7 @@ class InvalidRange(S3ClientError):
     def __init__(self, range_requested, actual_size, **kwargs):
         kwargs.setdefault("template", "range_error")
         self.templates["range_error"] = ERROR_WITH_RANGE
-        super(InvalidRange, self).__init__(
+        super().__init__(
             "InvalidRange",
             "The requested range is not satisfiable",
             range_requested=range_requested,
@@ -497,7 +515,7 @@ class InvalidContinuationToken(S3ClientError):
     code = 400
 
     def __init__(self, *args, **kwargs):
-        super(InvalidContinuationToken, self).__init__(
+        super().__init__(
             "InvalidArgument",
             "The continuation token provided is incorrect",
             *args,
@@ -511,7 +529,7 @@ class InvalidObjectState(BucketError):
     def __init__(self, storage_class, **kwargs):
         kwargs.setdefault("template", "storage_error")
         self.templates["storage_error"] = ERROR_WITH_STORAGE_CLASS
-        super(BucketError, self).__init__(
+        super().__init__(
             error_type="InvalidObjectState",
             message="The operation is not valid for the object's storage class",
             storage_class=storage_class,
@@ -523,41 +541,35 @@ class LockNotEnabled(S3ClientError):
     code = 400
 
     def __init__(self):
-        super(LockNotEnabled, self).__init__(
-            "InvalidRequest", "Bucket is missing ObjectLockConfiguration"
-        )
+        super().__init__("InvalidRequest", "Bucket is missing ObjectLockConfiguration")
 
 
 class AccessDeniedByLock(S3ClientError):
     code = 400
 
     def __init__(self):
-        super(AccessDeniedByLock, self).__init__("AccessDenied", "Access Denied")
+        super().__init__("AccessDenied", "Access Denied")
 
 
 class InvalidContentMD5(S3ClientError):
     code = 400
 
     def __init__(self):
-        super(InvalidContentMD5, self).__init__(
-            "InvalidContentMD5", "Content MD5 header is invalid"
-        )
+        super().__init__("InvalidContentMD5", "Content MD5 header is invalid")
 
 
 class BucketNeedsToBeNew(S3ClientError):
     code = 400
 
     def __init__(self):
-        super(BucketNeedsToBeNew, self).__init__(
-            "InvalidBucket", "Bucket needs to be empty"
-        )
+        super().__init__("InvalidBucket", "Bucket needs to be empty")
 
 
 class BucketMustHaveLockeEnabled(S3ClientError):
     code = 400
 
     def __init__(self):
-        super(BucketMustHaveLockeEnabled, self).__init__(
+        super().__init__(
             "InvalidBucketState",
             "Object Lock configuration cannot be enabled on existing buckets",
         )
@@ -567,7 +579,7 @@ class InvalidFilterRuleName(InvalidArgumentError):
     code = 400
 
     def __init__(self, value, *args, **kwargs):
-        super(InvalidFilterRuleName, self).__init__(
+        super().__init__(
             "filter rule name must be either prefix or suffix",
             "FilterRule.Name",
             value,
@@ -580,7 +592,7 @@ class InvalidTagError(S3ClientError):
     code = 400
 
     def __init__(self, value, *args, **kwargs):
-        super(InvalidTagError, self).__init__(
+        super().__init__(
             "InvalidTag", value, *args, **kwargs,
         )
 
@@ -589,7 +601,7 @@ class ObjectLockConfigurationNotFoundError(S3ClientError):
     code = 404
 
     def __init__(self):
-        super(ObjectLockConfigurationNotFoundError, self).__init__(
+        super().__init__(
             "ObjectLockConfigurationNotFoundError",
             "Object Lock configuration does not exist for this bucket",
         )
